@@ -1,11 +1,12 @@
 package Text::Hogan::Compiler;
-$Text::Hogan::Compiler::VERSION = '2.02';
+$Text::Hogan::Compiler::VERSION = '2.03';
 use Text::Hogan::Template;
 
 use 5.10.0;
 use strict;
 use warnings;
 
+use Ref::Util qw( is_arrayref );
 use Text::Trim 'trim';
 
 my $r_is_whitespace = qr/\S/;
@@ -403,12 +404,10 @@ sub esc {
 
 sub char_at {
     my ($text, $index) = @_;
-    if (ref($text) eq 'ARRAY') {
+    if (is_arrayref($text)) {
         return $text->[$index];
     }
-    else {
-        return substr($text, $index, 1);
-    }
+    return substr($text, $index, 1);
 }
 
 sub choose_method {
@@ -562,7 +561,7 @@ Text::Hogan::Compiler - parse templates and output Perl code
 
 =head1 VERSION
 
-version 2.02
+version 2.03
 
 =head1 SYNOPSIS
 
